<?php
namespace EMS\PortalFuncionario\Geral\Controllers;

use Zeedhi\Framework\DTO\{ Request, Response};
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

use EMS\PortalFuncionario\Geral\Services\ReportService;

class ReportController {

    /** @var ReportService */
    protected $reportService;

    public function __construct(
        ReportService $reportService
    ) {
        $this->reportService  = $reportService;
    }

    public function generateBirtReport(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();
            unset($row['requestType']);

            $reportLink = $this->reportService->generateBirtReport($row);

            $dataset = [
                'link' => $reportLink
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function downloadReport(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();
            $nrOrg = (int) $row['NRORG'];
            $link = (string) $row['link'];

            $file = $this->reportService->downloadReport($nrOrg, $link);

            $response->addDataSet(new DataSet('data', $file));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

}
