<?php
namespace Zeedhi\Framework\Cache\Type;

use Doctrine\Common\Cache\ApcuCache;
use Zeedhi\Framework\Cache\Cache;
use Zeedhi\Framework\Cache\Exception;

/**
 * Class ApcuImpl
 *
 * Class to provide an implementation of APCu Cache Driver
 *
 * @package Zeedhi\Framework\Cache
 */
class ApcuImpl extends ApcuCache implements Cache {

	/**
	 * {@inheritdoc}
	 */
	public function save($key, $value, $lifeTime = 0) {
		return $this->doSave($key, $value, $lifeTime);
	}

	/**
	 * {@inheritdoc}
	 */
	public function fetch($key) {
		if ($data = $this->doFetch($key)) {
			return $data;
		}
		throw Exception::valueNotFound($key);
	}

	/**
	 * {@inheritdoc}
	 */
	public function delete($key) {
		return $this->doDelete($key);
	}

	/**
	 * {@inheritdoc}
	 */
	public function contains($key){
		return $this->doContains($key);
	}

	/**
	 * {@inheritdoc}
	 */
	public function saveMultiple(array $keysAndValues, $lifetime = 0) {
		return $this->doSaveMultiple($keysAndValues, $lifetime);
	}

	/**
	 * {@inheritdoc}
	 */
	public function fetchMultiple(array $keys) {
		return $this->doFetchMultiple($keys);
	}

	/**
	 * {@inheritdoc}
	 */
	public function deleteMultiple(array $keys) {
		return $this->doDeleteMultiple($keys);
	}
	
}